package adminuser

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/shopping-service-client/api"
	"sghgogs.com/micro/shopping-service-client/domain/model/base"
	model_res "sghgogs.com/micro/shopping-service-client/domain/model/response"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
	"time"
)

type ListResponse struct {
	Items      []model_res.User `json:"items"`
	TotalCount int64            `json:"total_count"`
}

// GetAdminUserList
// @summary 列表
// @Tags AdminUsers
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param page query int true "页码"
// @Param page_size query int true "每页数量"
// @Param keyword query string false "关键字"
// @Param status query string false "状态" Enums(enabled, disabled)
// @Success 200 {object} response.ApiResponse{data=ListResponse} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/manager/users [get]
func (svc *AdminUser) GetAdminUserList(c *gin.Context) {
	keyword := c.Query("keyword")
	queryPage := c.DefaultQuery("page", "1")
	queryPageSize := c.DefaultQuery("page_size", "10")
	page, _ := strconv.Atoi(queryPage)
	pageSize, _ := strconv.Atoi(queryPageSize)
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingAdminUserService.GetAdminUserList")
	list, err := svc.Service.GetAdminUserList(ctx, &pb.GetAdminUserListRequest{
		Page:     int32(page),
		PageSize: int32(pageSize),
		Keyword:  keyword,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	users := make([]model_res.User, 0)
	for _, item := range list.Items {
		users = append(users, svc.getUserRes(item))
	}
	c.JSON(http.StatusOK, res.SuccessResponse(ListResponse{
		TotalCount: list.TotalCount,
		Items:      users,
	}))
}

type baseResponse struct {
	Items []base.ListMapItem `json:"items"`
}

// GetAllAdminUser
// @summary 所有
// @Tags AdminUsers
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Success 200 {object} response.ApiResponse{data=baseResponse} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/manager/all_users [get]
func (svc *AdminUser) GetAllAdminUser(c *gin.Context) {
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingAdminUserService.GetAllAdminUser")
	list, err := svc.Service.GetAllAdminUser(ctx, &pb.GetAllAdminUserRequest{})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	roles := make([]base.ListMapItem, 0)
	for _, item := range list.Items {
		roles = append(roles, base.ListMapItem{
			Key:   item.Key,
			Value: item.Value,
		})
	}
	c.JSON(http.StatusOK, res.SuccessResponse(baseResponse{
		Items: roles,
	}))
}

// GetAdminUser
// @summary 详情
// @Tags AdminUsers
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "用户 ID"
// @Success 200 {object} response.ApiResponse{data=model_res.User} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/manager/user/{user_id} [get]
func (svc *AdminUser) GetAdminUser(c *gin.Context) {
	UserID, err := strconv.ParseInt(c.Param("user_id"), 10, 64)
	if err != nil || UserID <= 0 {
		c.JSON(http.StatusBadRequest, gin.H{"error": "Invalid UserID"})
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingAdminUserService.GetAdminUser")
	result, err := svc.Service.GetAdminUser(ctx, &pb.GetAdminUserRequest{UserId: UserID})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(http.StatusBadRequest, res.ErrorResponse(code, mgs))
		return
	}
	userRes := api.GetUserRes(result.Data)
	userRes.Roles = svc.getBaseRolesRes(result.Data.Roles)
	c.JSON(http.StatusOK, res.SuccessResponse(userRes))
}

func (svc *AdminUser) getUserRes(user *pb.User) model_res.User {
	toStatus, _ := base.MapEnumToStatus(user.Status)
	var at *time.Time
	if user.UpdatedAt > 0 {
		toTime := utils.ConvertInt64ToTime(user.UpdatedAt)
		at = &toTime
	}
	return model_res.User{
		ID:          user.Id,
		Username:    user.Username,
		PhoneNumber: user.PhoneNumber,
		Email:       user.Email,
		Avatar:      user.Avatar,
		CreatedAt:   utils.ConvertInt64ToTime(user.CreatedAt),
		UpdatedAt:   at,
		Status:      toStatus,
	}
}

func (svc *AdminUser) getBaseRolesRes(values []*pb.Base) []base.ListMapItem {
	items := make([]base.ListMapItem, 0)
	for _, item := range values {
		items = append(items, base.ListMapItem{
			Key:   item.Key,
			Value: item.Value,
		})
	}
	return items
}
