package adminuser

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/common"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

type UpdateAdminUserRequest struct {
	Roles       []int64 `json:"roles" binding:"required"`
	PhoneNumber string  `json:"phone_number" binding:"required"`
	Email       string  `json:"email"`
	Avatar      string  `json:"avatar"`
}

// UpdateAdminUser
// @summary 更新角色
// @Tags AdminUsers
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "用户 ID"
// @Param body body UpdateAdminUserRequest true "请求body"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/manager/user/{user_id} [put]
func (svc *AdminUser) UpdateAdminUser(c *gin.Context) {
	var req UpdateAdminUserRequest
	userID, err := strconv.ParseInt(c.Param("user_id"), 10, 64)
	if err != nil || userID <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, common.ErrorMessage[common.InvalidUserID]))
		return
	}
	if err = c.BindJSON(&req); err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	if isBool, err := common.ValidateNumericInt64(req.Roles); !isBool {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	if common.IsValidPhoneNumber(req.PhoneNumber) {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, "手机号格式有误"))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingAdminUserService.UpdateAdminUser")
	_, err = svc.Service.UpdateAdminUser(ctx, &pb.UpdateAdminUserRequest{
		UserId:      userID,
		Roles:       req.Roles,
		PhoneNumber: req.PhoneNumber,
		Email:       req.Email,
		Avatar:      req.Avatar,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
