package auth

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/shopping-service-client/domain/model/base"
	model_res "sghgogs.com/micro/shopping-service-client/domain/model/response"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type LoginRequest struct {
	Username string `json:"username" binding:"required"`
	Password string `json:"password" binding:"required"`
	Code     string `json:"code" binding:"required"`
}

type LoginResponse struct {
	Token   string         `json:"token"`
	Profile model_res.User `json:"profile"`
}

// Login
// @summary 登录
// @Tags Auth
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param body body LoginRequest true "请求body"
// @Success 200 {object} response.ApiResponse{data=LoginResponse} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/login [post]
func (svc *Auth) Login(c *gin.Context) {
	var req LoginRequest
	if err := c.ShouldBindJSON(&req); err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingAuthService.Login")
	login, err := svc.Service.Login(ctx, &pb.LoginRequest{
		Username: req.Username,
		Password: req.Password,
		Code:     req.Code,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(LoginResponse{
		Token:   login.Token,
		Profile: svc.getProfileRes(login.Data),
	}))
}

func (svc *Auth) getProfileRes(user *pb.User) model_res.User {
	return model_res.User{
		ID:          user.Id,
		Username:    user.Username,
		PhoneNumber: user.PhoneNumber,
		Email:       user.Email,
		Avatar:      user.Avatar,
		CreatedAt:   utils.ConvertInt64ToTime(user.CreatedAt),
		Roles:       svc.getBaseRolesRes(user.Roles),
	}
}
func (svc *Auth) getBaseRolesRes(values []*pb.Base) []base.ListMapItem {
	items := make([]base.ListMapItem, 0)
	for _, item := range values {
		items = append(items, base.ListMapItem{
			Key:   item.Key,
			Value: item.Value,
		})
	}
	return items
}
