package order

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/shopping-service-client/api"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

// GetOrderList
// @Description "状态" Enums(1,2,3,4,5,6,7) Description("1: 待支付,2: 支付中, 3: 支付成功, 4: 支付失败, 5:取消支付, 6:退款中, 7:已退款) "支付方式" Enums(1,2,3,4,5,6,7) Description("1: 支付宝,2: 微信支付, 3: 银行卡, 4: 信用卡, 5:虚拟钱包, 6:线下支付, 7:账户余额)
// @summary 列表
// @Tags 订单管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param page query int true "页码"
// @Param page_size query int true "每页数量"
// @Param keyword query string false "关键字"
// @Param status query int false "状态" Enums(1,2,3,4,5,6,7) Description("1: 待支付,2: 支付中, 3: 支付成功, 4: 支付失败, 5:取消支付, 6:退款中, 7:已退款)
// @Param payment_method query int false "支付方式" Enums(1,2,3,4,5,6,7) Description("1: 支付宝,2: 微信支付, 3: 银行卡, 4: 信用卡, 5:虚拟钱包, 6:线下支付, 7:账户余额)
// @Success 200 {object} response.ApiResponse{data=listResponse} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/orders [get]
func (svc *Order) GetOrderList(c *gin.Context) {
	keyword := c.Query("keyword")
	queryPage := c.DefaultQuery("page", "1")
	queryPageSize := c.DefaultQuery("page_size", "10")
	statusValue := c.DefaultQuery("status", "-1")
	paymentMethodValue := c.DefaultQuery("payment_method", "-1")
	page, _ := strconv.Atoi(queryPage)
	pageSize, _ := strconv.Atoi(queryPageSize)
	status, _ := strconv.Atoi(statusValue)
	paymentMethod, _ := strconv.Atoi(paymentMethodValue)
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingOrderService.GetOrderList")
	list, err := svc.Service.GetOrderList(ctx, &pb.GetOrderListRequest{
		Page:          int32(page),
		PageSize:      int32(pageSize),
		Status:        pb.OrderStatusEnum(status),
		PaymentMethod: pb.PaymentMethodEnum(paymentMethod),
		Keyword:       keyword,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(listResponse{
		TotalCount: list.TotalCount,
		Items:      api.GetOrderListRes(list.Items),
	}))
}

// GetOrder
// @summary 详情
// @Tags 权限项管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    order_id   path      int  true  "Order ID"
// @Success 200 {object} response.ApiResponse{data=api.OrderItem} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/order/{order_id} [get]
func (svc *Order) GetOrder(c *gin.Context) {
	orderID, err := strconv.ParseInt(c.Param("order_id"), 10, 64)
	if err != nil || orderID <= 0 {
		c.JSON(http.StatusBadRequest, gin.H{"error": "Invalid orderID"})
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingOrderService.GetOrder")
	result, err := svc.Service.GetOrder(ctx, &pb.GetOrderRequest{OrderId: orderID})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(http.StatusBadRequest, res.ErrorResponse(code, mgs))
		return
	}
	orderItem := api.GetOrderRes(*result.Data)
	if result.Data.OrderItems != nil {
		orderItem.OrderItems = api.GetOrderItemsRes(result.Data.OrderItems)
	}
	if result.Data.Address != nil {
		orderItem.Address = api.GetAddressResItem(result.Data.Address)
	}
	c.JSON(http.StatusOK, res.SuccessResponse(orderItem))
}
