package permission

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/common"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

type UpdatePermissionRequest struct {
	Description string  `json:"description"` // 描述
	Roles       []int64 `json:"roles"`
	Endpoint    string  `json:"endpoint" binding:"required"` // API
}

// UpdatePermission
// @summary 更新
// @Tags 权限项管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "权限项 ID"
// @Param body body UpdatePermissionRequest true "请求body"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/permission/{permission_id} [put]
func (svc *Permission) UpdatePermission(c *gin.Context) {
	var req UpdatePermissionRequest
	permissionID, err := strconv.ParseInt(c.Param("permission_id"), 10, 64)
	if err != nil || permissionID <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, "Invalid permissionID"))
		return
	}
	if err = c.BindJSON(&req); err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	if len(req.Roles) > 0 {
		if isBool, err := common.ValidateNumericInt64(req.Roles); !isBool {
			c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
			return
		}
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingPermissionService.UpdatePermission")
	_, err = svc.Service.UpdatePermission(ctx, &pb.UpdatePermissionRequest{
		PermissionId: permissionID,
		Description:  req.Description,
		Roles:        req.Roles,
		Endpoint:     req.Endpoint,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
