package role

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/common"
	"sghgogs.com/micro/shopping-service-client/domain/model/base"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

type ToggleRequest struct {
	Status base.Status `json:"status" binding:"required"` // ENABLED | DISABLED | DELETED
}

// ToggleRole
// @summary 更新状态
// @Tags 角色管理 Roles
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "角色 ID"
// @Param body body ToggleRequest true "请求body"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/role/{role_id}/toggle [put]
func (svc *Role) ToggleRole(c *gin.Context) {
	var req ToggleRequest
	roleID, err := strconv.ParseInt(c.Param("role_id"), 10, 64)
	if err != nil || roleID <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, common.ErrorMessage[common.InvalidRoleID]))
		return
	}
	if err = c.BindJSON(&req); err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingRoleService.ToggleRole")
	enum, err := base.MapStatusToEnum(req.Status)
	if err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	_, err = svc.Service.ToggleRole(ctx, &pb.ToggleRoleRequest{
		RoleId: roleID,
		Status: enum,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
